from flask import (
        Blueprint, flash, g, redirect, render_template, request, session, url_for
        )

from pool_log.db import get_db

bp = Blueprint('pool', __name__, url_prefix='/pools')

@bp.route('/create', methods=('GET', 'POST'))
def create():
    if request.method == 'POST':
        name = request.form['name']
        volume = request.form['volume']
        db = get_db()
        error = None

        if not name:
            error = "Pool name required"
        elif not volume:
            error = "Pool volume required"

        if error is None:
            try:
                db.execute(
                        "INSERT INTO pool (name, volume) VALUES (?, ?)", 
                        (name, volume),
                        )
                db.commit()
            except db.IntegrityError:
                error = f"There is already a pool named {name}"
            else:
                return redirect(url_for('index'))

        flash(error)

    return render_template("pools/create.html")

@bp.route('/select', methods=('GET', 'POST'))
def select():
    db = get_db()
    pools = db.execute(
            'SELECT id, name, volume FROM pool'
            ).fetchall()

    if request.method == 'POST':
        session.clear()
        session['pool_id'] = request.form['pool']
        return redirect(url_for('index'))

        
    return render_template('pools/select.html', pools=pools)



import sqlite3

import click
from flask import current_app, g, session

def get_db():
    if 'db' not in g:
        g.db = sqlite3.connect(
                current_app.config['DATABASE'],
                detect_types=sqlite3.PARSE_DECLTYPES
                )
        g.db.row_factory = sqlite3.Row

        return g.db

def close_db(e=None):
    db = g.pop('db', None)

    if db is not None:
        db.close()

def init_db():
    db = get_db()

    with current_app.open_resource('schema.sql') as f:
        db.executescript(f.read().decode('utf8'))

@click.command('init-db')
def init_db_command():
    # Clear the existing data and create new tables
    init_db()
    click.echo('Initialized the database')

# Register the db functions with the application that is passed in.
def init_app(app):
    # Clear connection to db when response is returned
    app.teardown_appcontext(close_db)
    app.cli.add_command(init_db_command)



from flask import(
        Blueprint, flash, g, redirect, render_template, request, session, url_for
        )

from pool_log.db import get_db


bp = Blueprint('log', __name__)


@bp.route('/', methods=('GET', 'POST'))
def index():
    db = get_db()
    if "pool_id" in session:
        logs = db.execute(
                'SELECT id, created, temperature, ph, chlorine, cya, pressure, clarity'
                ' FROM log l WHERE pool = ?'
                ' ORDER BY created DESC',
                (session['pool_id'],)
                ).fetchall()
        pool = db.execute(
                'SELECT name, volume FROM pool WHERE id = ?',
                (session['pool_id'],)
                ).fetchone()
    else:
        return redirect(url_for('pool.select'))

    return render_template('log/index.html', logs=logs, pool=pool)

@bp.route('/create', methods=('GET', 'POST'))
def create():
    if request.method == 'POST':
        # Get info from the form
        temperature = request.form['temperature']
        ph = request.form['ph']
        chlorine = request.form['chlorine']
        cya = request.form['cya']
        pressure = request.form['pressure']
        clarity = request.form['clarity']
        error = None
        # Add in errors

        if error is None:
            try:
                db = get_db()
                db.execute(
                        # Insert log values into db
                        'INSERT INTO log (temperature, ph, chlorine, cya, pressure, clarity, pool)'
                        ' VALUES (?, ?, ?, ?, ?, ?, ?)',
                        (temperature, ph, chlorine, cya, pressure, clarity, session['pool_id'])
                        )
                db.commit()
            except db.IntegrityError:
                # Add in the error
                pass
            else:
                return redirect(url_for('index'))

            flash(error)

        return redirect(url_for('index'))

    db = get_db()
    last_log = db.execute(
                'SELECT id, created, temperature, ph, chlorine, cya, pressure, clarity'
                ' FROM log l WHERE pool = ?'
                ' ORDER BY created DESC',
                (session['pool_id'],)
                ).fetchone()

    return render_template('log/create.html', last_log=last_log)




import os
from flask import Flask
import click

def create_app(test_config=None):
    app = Flask(__name__, instance_relative_config=True)
    app.config.from_mapping(
            SECRET_KEY='dev',
            DATABASE=os.path.join(app.instance_path, 'pool_log.sqlite'),
            )

    if test_config is None:
        # Load the instance configuration file
        app.config.from_pyfile('config.py', silent=True)
    else:
        # Load the test config if passed as an argument
        app.config.from_mapping(test_config)

    # Make sure the instant folder exists
    try:
        os.makedirs(app.instance_path)
    except OSError:
        pass

    @app.route('/hello')
    def hello():
        return 'Hello World!!!'

    from . import db
    db.init_app(app)

    from . import log, pool
    app.register_blueprint(log.bp)
    app.register_blueprint(pool.bp)
    app.add_url_rule('/', endpoint='index')

    return app

